@@ -1,10 +1,8 @@
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
-# Copyright (C) 2009 Yukikaze
+# Copyright (C) 2009-2010 Yukikaze
 
-__author__="yukikaze"
-__date__ ="$2009/09/14 17:38:25$"
 import glob
 import n_gram
 import os
@@ -113,12 +111,14 @@ def veryfySize(path):
     #vsize=[297,497,596,1196]#SD 30m 1h 1.5h 2h
     vsize=[245,275,295,591,830]
     vsize=vsize+[325,449,560,590,602,690,805,860,1014,1138,1237]
-    #vsize=vsize+[458,916]#HD 30m 1h
+    vsize=vsize+[261,535,540,616,740]#HD 30m 1h
     #vsize=vsize+[381,895,447]
     ret = 0
     for size in vsize:
         if os.path.getsize(path)>(size-10)*1024*1024 and os.path.getsize(path)<(size+10)*1024*1024:
             ret=1
+    if os.path.getsize(path)>270*1024*1024:
+        ret=1
     return ret
 def searchFolder(title,path):
     """
@@ -152,13 +152,10 @@ def searchFolder(title,path):
         else:
             cmpp=os.path.basename(dirp)
             appp=os.path.dirname(dirp)
-        rT=re.compile("(.+)_(\d*)\Z")
-        tT=rT.match(title)
-        tT2=rT.match(cmpp)
-        if tT:
-            ntitle=tT.group(0)
-        if tT2:
-            cmpp=cmpp.group(0)
+        ntitle=getTitle(title)
+        #recdblist.printutf8(cmpp)
+        cmpp=getTitle(os.path.splitext(cmpp)[0])
+        #recdblist.printutf8(cmpp+"\n")
         p=n_gram.trigram(ntitle,cmpp)
         if p>0:
             ngram.append((p,appp))
@@ -167,28 +164,55 @@ def searchFolder(title,path):
     ngram.reverse()
     if len(ngram)>0:
         #recdblist.printutf8(title + ngram[0][1] + " : "+str(ngram[0][0]))
-        if ngram[0][0]>400:
+        if ngram[0][0]>500:
             return ngram[0][1]
         else:
             return ""
     else:
         return ""
+def getTitle(title):
+    rT=re.compile("(.+)_(\d+)\Z")
+    tT=rT.match(title)
+    rT2=re.compile("(.+)_(.+)_(\d*)\Z")#_(aichi)_2010-02-06T01:59:00.mkv
+    tT2=rT2.match(title)
+    rT3=re.compile("(.+)_(.+)_\d+-\d+-\d+T\d+:\d+:\d+\Z")#_(aichi)_2010-02-06T01:59:00.mkv
+    tT3=rT3.match(title)
+    rT4=re.compile("(.+)_(.+)_\d+-\d+-\d+T\d+-\d+-\d+\Z")#_(aichi)_2010-02-06T01-59-00.mkv
+    tT4=rT4.match(title)
+    rT5=re.compile("(.+)_(.+)_(.+)\Z")#_(aichi)_2010-02-06T01-59-00.mkv
+    tT5=rT5.match(title)
+    ntitle=title
+    if tT :
+        ntitle=tT.group(1)
+    elif tT2:
+        ntitle=tT2.group(1)
+    elif tT3:
+        ntitle=tT3.group(1)
+    elif tT4:
+        ntitle=tT4.group(1)
+    elif tT5:
+        ntitle=tT5.group(1)
+    return ntitle
 def execMove(title,temppath,recpath):
-    srcpath=os.path.join(temppath,title+".mp4")
+    srcpath=os.path.join(temppath,title+".mkv")
     #desttitle=destName(title, temppath, recpath)
     
     sf=searchFolder(title, recpath)
     if sf!="":
-        destpath=os.path.join(sf,destNameMP4(title, temppath, sf)+".mp4")
+        destpath=os.path.join(sf,destNameMKV(title, temppath, sf)+".mkv")
         #os.path.join(sf,desttitle+".mkv")
         #recdblist.printutf8(srcpath)
         #recdblist.printutf8(destpath)
         recdblist.printutf8("moving now..")
         recdblist.printutf8(srcpath+" : "+destpath)
+        print srcpath
         shutil.move(srcpath, destpath)
         #shutil.copy(srcpath, destpath)
         delpath=[os.path.join(temppath,title+".ts")]
         delpath.append(os.path.join(temppath,title+".avi"))
+        delpath.append(os.path.join(temppath,title+".120.avi"))
+        delpath.append(os.path.join(temppath,title+".timecode.txt"))
+        delpath.append(os.path.join(temppath,title+".aac"))
         delpath.append(os.path.join(temppath,title+".ts.b25"))
         delpath.append(os.path.join(temppath,title+".ts.tsmix"))
         delpath.append(os.path.join(temppath,title+".ts.log"))
@@ -281,26 +305,26 @@ if __name__ == "__main__":
         #print opts.ltitle
         ltitle=unicode(opts.ltitle,'utf-8')
         sf=searchFolder(ltitle, recordedpath)
-        recdblist.printutf8(os.path.join(sf, destNameMP4(ltitle,recpath,sf)+".mp4"))
+        recdblist.printutf8(os.path.join(sf, destNameMKV(ltitle,recpath,sf)+".mkv"))
         #print os.path.join(sf, destNameMP4(ltitle,recpath,sf)+".mp4")
     elif opts.auto:
-        sa=search_mp4(recpath, recordedpath)
+        sa=search_mkv(recpath, recordedpath)
         for t in sa:
             recdblist.printutf8(u"自動推測実行中")
             sf=searchFolder(t,recordedpath)
             if sf!="":
                 recdblist.printutf8(u"移動先")
-                recdblist.printutf8(t+" : "+os.path.join(sf, destNameMP4(t, recpath,sf)+".mp4"))
+                recdblist.printutf8(t+" : "+os.path.join(sf, destNameMKV(t, recpath,sf)+".mkv"))
                 recdblist.printutf8(u"実行中")
                 execMove(t, recpath, recordedpath)
             else:
                 recdblist.printutf8(t+" can't find matching folder.")
     elif opts.list:
-        sa=search_mp4(recpath, recordedpath)
+        sa=search_mkv(recpath, recordedpath)
         for t in sa:
             sf=searchFolder(t,recordedpath)
             if sf!="":
-                recdblist.printutf8(t+u" : "+os.path.join(sf, destNameMP4(t, recpath,sf)+".mp4"))
+                recdblist.printutf8(t+u" : "+os.path.join(sf, destNameMKV(t, recpath,sf)+".mkv"))
     elif opts.etitle!="":
         etitle=unicode(opts.etitle,'utf-8')
         execMove(etitle,recpath, recordedpath)
