@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
-# Copyright (C) 2009 Yukikaze
+# Copyright (C) 2009-2010 Yukikaze
 import datetime
 import os
 import os.path
@@ -22,6 +22,7 @@ import status
 import tv2avi
 import tv2mkv
 import tv2mp4
+import install
 import recdblist
 recpath = configreader.getpath('recpath')
 movepath = configreader.getpath('move_destpath')
@@ -31,10 +32,15 @@ def task():
     数分毎に実行されるタスク処理
     予定によって子プロセスを生成し処理する。
     """
+    try:
+        if rec10d.rec10db.select_installed_in_status()==0:
+            install.install()
+    except:
+        install.install()
     recdb.delete_old("24")
     recdb.delete_old_auto_bayes("1")
     recdb.delete_old_auto_keyword("1")
-    tasks = recdb.getnow("2")
+    tasks = recdb.getnow("3")
     inum = recdb.countRecNow_minutes("10")
     recdblist.printutf8(u"rec10処理開始"+ datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"))
     recdblist.printutf8(u"直近録画予約件数:" + str(inum) + u"BS/CS録画中件数:" + str(status.getBSCSRecording()) + u"TE録画中件数:" + str(status.getTERecording()) )
@@ -54,6 +60,7 @@ def task():
         if pid!=0:
             ""
         else:
+            time.sleep(10)
             auto_process.auto_check(recpath)
             sys.exit()
     update = chdb.update()
@@ -168,7 +175,8 @@ def task():
                 else:
                     recdb.del_reckey(recdblist.REC_AVI_TO_MKV, title, chtxt, btime)
                     recdb.rec_reckey(recdblist.REC_CHANGING_CANTAINER, title, chtxt, btime, etime, opt)
-                    tv2mkv.avi2mkv(os.path.join(recpath,title+".avi"),os.path.join(recpath,title+".mkv"))
+                    #tv2mp4.avi2mp4(os.path.join(recpath,title+".avi"),os.path.join(recpath,title+".mkv"),opt)
+                    tv2mkv.avi2mkv(os.path.join(recpath,title+".avi"),os.path.join(recpath,title+".mkv"),opt)
                     recdb.del_reckey(recdblist.REC_CHANGING_CANTAINER, title, chtxt, btime)
                     sys.exit()
         elif task["type"] == recdblist.REC_AVI_TO_MP4:
@@ -179,7 +187,7 @@ def task():
                 else:
                     recdb.del_reckey(recdblist.REC_AVI_TO_MP4, title, chtxt, btime)
                     recdb.rec_reckey(recdblist.REC_CHANGING_CANTAINER, title, chtxt, btime, etime, opt)
-                    tv2mp4.avi2mp4(os.path.join(recpath,title+".avi"),os.path.join(recpath,title+".mp4"))
+                    tv2mp4.avi2mp4(os.path.join(recpath,title+".avi"),os.path.join(recpath,title+".mp4"),opt)
                     recdb.del_reckey(recdblist.REC_CHANGING_CANTAINER, title, chtxt, btime)
                     sys.exit()
         elif task["type"] == recdblist.REC_MKV_TO_MP4:
@@ -188,7 +196,7 @@ def task():
                 if pid > 0:#親プロセスの場合
                     ""
                 else:
-                    recdb.del_reckey(recdblist.REC_AVI_TO_MP4, title, chtxt, btime)
+                    recdb.del_reckey(recdblist.REC_MKV_TO_MP4, title, chtxt, btime)
                     recdb.rec_reckey(recdblist.REC_CHANGING_CANTAINER, title, chtxt, btime, etime, opt)
                     tv2mp4.mkv2mp4(os.path.join(recpath,title+".mkv"),os.path.join(recpath,title+".mp4"))
                     recdb.del_reckey(recdblist.REC_CHANGING_CANTAINER, title, chtxt, btime)
@@ -209,12 +217,30 @@ def search_keyword(key):
                 ett = datetime.datetime.strptime(etimet, "%Y-%m-%d %H:%M:%S")
                 btimet = btt.strftime("%Y-%m-%d %H:%M:%S")
                 etimet = ett.strftime("%Y-%m-%d %H:%M:%S")
-                try:
-                    recdb.add_auto_keyword(chtxtt, titlet, btimet, etimet)
-                except Exception, inst:
-                    print "error occures in search_keyword"
-                    print type(inst)
-                    print inst
+                if status.getSettings_auto_jbk()==1:
+                    topt=status.getSettings_auto_opt()
+                    try:
+                        maxnum=0
+                        if len(ch['ch'])>2:
+                            maxnum=epgdb.count_schedule_timeline(btimet, etimet)[1]
+                            maxnum=int(configreader.getenv("bscs_max"))-maxnum
+                        else:
+                            maxnum=epgdb.count_schedule_timeline(btimet, etimet)[0]
+                            maxnum=int(configreader.getenv("te_max"))-maxnum
+                        if maxnum>0:
+                            topt=status.getSettings_auto_opt()
+                            recdb.recreserv(titlet,chtxtt, btimet, etimet,topt)
+                    except Exception, inst:
+                        print "error occures in search_keyword_auto_jbk"
+                        print str(type(inst))
+                        print str(inst)
+                else:
+                    try:
+                        recdb.add_auto_keyword(chtxtt, titlet, btimet, etimet)
+                    except Exception, inst:
+                        print "error occures in search_keyword"
+                        print str(type(inst))
+                        print str(inst)
 def type_reserve(typetxt,chtxt,title,bt,et,opt):
     btime = bt.strftime("%Y-%m-%d %H:%M:%S")
     etime = et.strftime("%Y-%m-%d %H:%M:%S")
@@ -252,9 +278,9 @@ def type_reserve(typetxt,chtxt,title,bt,et,opt):
                     auto_rec.add_key("ALL", titlen,exp+" "+longexp)
                     recdblist.printutf8(u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen)
                 except Exception, inst:
-                    print "Error happended in Oikake DB"
-                    print type(inst)
-                    print inst
+                    print "Error happened in Oikake DB"
+                    print str(type(inst))
+                    print str(inst)
             else:
                 recdblist.printutf8(u"追いかけ機能エラー：番組データが見付かりません。")
         else:
@@ -283,7 +309,7 @@ def type_reserve(typetxt,chtxt,title,bt,et,opt):
                 auto_rec.add_key("ALL", titlen,exp+" "+longexp)
                 recdblist.printutf8(u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen)
             except Exception, inst:
-                print "Error happended in Oikake DB"
+                print "Error happened in Oikake DB"
                 print type(inst)
                 print inst
     elif dt <= 20 * 60:
@@ -312,18 +338,24 @@ def type_final(typetxt,chtxt,title,bt,et,opt):
         testpath=[os.path.join(recpath,title+".ts.b25")]
         testpath.append(os.path.join(recpath,title+".ts"))
         testpath.append(os.path.join(recpath,title+".avi"))
-        testpath.append(os.path.join(recpath,title+".mkv"))
+        testpath.append(os.path.join(recpath,title+".mp4"))
         testpath.append(os.path.join(recpath,title+".log"))
         tcheck=0
         for ti in testpath:
             if os.path.exists(ti):
                 tcheck=tcheck+1
         if re.search("N", opt) or tcheck>0:
-            newtitle=newtitle+u"_"+bt.strftime("%Y%m%d%H%M")
+            iff=""
+            try:
+                iff=u"("+configreader.getenv("iff")+u")_"
+            except:
+                iff=""
+            newtime=bt
+            newtitle=newtitle+u"_"+iff+newtime.strftime("%Y-%m-%dT%H-%M-%S")
         recdb.rec_reckey(typetxting, newtitle, chtxt, btime, etime, opt)
         recdblist.printutf8(u"録画開始 "+newtitle+" "+btime+" "+etime)
         tv2avi.timetv2b25(recpath + "/" + newtitle + ".avi", chtxt, btime, etime, opt)
-        recdb.del_reckey(typetxting, title, chtxt, btime)
+        recdb.del_reckey(typetxting, newtitle, chtxt, btime)
         if not re.search("R", opt):
             tnow = datetime.datetime.now()
             bt = datetime.datetime.strptime(btime, "%Y-%m-%d %H:%M:%S")
@@ -335,7 +367,10 @@ def type_final(typetxt,chtxt,title,bt,et,opt):
             etime = et.strftime("%Y-%m-%d %H:%M:%S")
             recdb.rec_reckey(typetxtdecque, newtitle, chtxt, btime, etime, opt)
         else:
-            shutil.copy(os.path.join(recpath,title+".ts.b25"), os.path.join(movepath,title+".ts.b25"))
+            try:
+                shutil.copy(os.path.join(recpath,title+".ts.b25"), os.path.join(movepath,title+".ts.b25"))
+            except:
+                ""
             recdb.rec_reckey(recdblist.REC_MOVE_END, newtitle, chtxt, btime, etime, opt)
         sys.exit()
 def type_keyword(typetxt,chtxt,title,bt,et,opt,deltatime):
@@ -428,6 +463,11 @@ def type_decode_que(typetxt,chtxt,title,bt,et,opt):
             if not os.access(recpath + "/" + title + ".ts", os.F_OK):
                 recdb.del_reckey(typetxting, title, chtxt, btime)
                 recdb.rec_reckey(typetxtmiss, title, chtxt, btime, etime, opt)
+            else:
+                ch=checker.checkB25Decode(recpath + "/" + title + ".ts.b25", recpath + "/" + title + ".ts")
+                print ch
+                if ch == 1:
+                    os.remove(recpath + "/" + title + ".ts.b25")
             bt = datetime.datetime.strptime(btime, "%Y-%m-%d %H:%M:%S")
             et = datetime.datetime.strptime(etime, "%Y-%m-%d %H:%M:%S")
             dt = et-bt
@@ -439,16 +479,15 @@ def type_decode_que(typetxt,chtxt,title,bt,et,opt):
                 etime = et.strftime("%Y-%m-%d %H:%M:%S")
                 recdb.rec_reckey(typetxtencque, title, chtxt, btime, etime, opt)
             else:
-                if opt.rfind("d")>=0:
-                    shutil.copy(os.path.join(recpath,title+".sa.avi"),os.path.join(movepath,title+".sa.avi"))
-                elif opt.rfind("5")>=0:
-                    shutil.copy(os.path.join(recpath,title+".sa.avi"),os.path.join(movepath,title+".sa.avi"))
-                else:
+                try:
                     shutil.copy(os.path.join(recpath,title+".ts"), os.path.join(movepath,title+".ts"))
+                except Exception, inst:
+                    errtxt="Error happened in type_decode_que in timerec.\n"
+                    errtxt=errtxt+"move ts error.\n"
+                    errtxt=errtxt+str(type(inst))+"\n"
+                    errtxt=errtxt+str(inst)
+                    recdblist.addlog(os.path.join(recpath,title+".ts"), errtxt, "timerec-move(Decode) error")
                 recdb.rec_reckey(recdblist.REC_MOVE_END, title, chtxt, btime, etime, opt)
-            #recdblist.printutf8(checker.checkB25Decode(recpath + "/" + title + ".ts.b25", recpath + "/" + title + ".ts"))
-            if checker.checkB25Decode(recpath + "/" + title + ".ts.b25", recpath + "/" + title + ".ts") == 1:
-                os.remove(recpath + "/" + title + ".ts.b25")
         else:
             recdb.del_reckey(typetxtnow, title, chtxt, btime)
             bt = bt + datetime.timedelta(seconds=600)
@@ -472,24 +511,43 @@ def type_encode_que(typetxt,chtxt,title,bt,et,opt):
         typetxtfin=recdblist.REC_FIN_LOCAL
     if dt < 10 * 60:
         if status.getEncoding() < int(configreader.getenv("enc_max")):
+            recdb.del_reckey(typetxtnow, title, chtxt, btime)
+            recdb.rec_reckey(typetxting, title, chtxt, btime, etime, opt)
             recdblist.printutf8(opt)
             pin = recpath + "/" + title + ".ts"
             if re.search("d", opt):
-                pin = recpath + "/" + title + ".sa.avi"
-            if re.search("5", opt):
-                pin = recpath + "/" + title + ".sa.avi"
-            #pout = recpath + "/" + title + ".avi"
-            pout = recpath + "/" + title + ".mp4"
+                pin = recpath + "/" + title + ".m2v"
+                if not os.path.exists(pin) or os.path.getsize(pin)<100*1000:
+                    paac2 = recpath + "/" + title + "_2.aac"
+                    pmp32 = recpath + "/" + title + "_2.mp3"
+                    if not os.path.exists(paac2) and not os.path.exists(pmp32):
+                        tv2avi.dualaudio2sep(os.path.join(recpath, title+".ts"),"167")
+                time.sleep(3)
+            elif re.search("5", opt):
+                pin = recpath + "/" + title + ".m2v"
+                if not os.path.exists(pin) or os.path.getsize(pin)<100*1000:
+                    paac2 = recpath + "/" + title + "_2.aac"
+                    pmp32 = recpath + "/" + title + "_2.mp3"
+                    if not os.path.exists(paac2) and not os.path.exists(pmp32):
+                        tv2avi.pentaaudio2sep(os.path.join(recpath, title+".ts"))
+                time.sleep(3)
+            pout = recpath + "/" + title + ".mkv"
             recdblist.printutf8(pin)
-            #recdblist.printutf8(pin+":"+pout+":"+opt)
-            recdb.del_reckey(typetxtnow, title, chtxt, btime)
-            recdb.rec_reckey(typetxting, title, chtxt, btime, etime, opt)
-            #tv2mkv.ts2mkv(pin, pout, opt)
-            tv2mp4.ts2mp4(pin, pout, opt)
-            #tv2avi.ts2avi(pin, pout, opt)
+            tv2mkv.ts2mkv(pin, pout, opt)
             recdb.del_reckey(typetxting, title, chtxt, btime)
+            time.sleep(10)
             if re.search("E", opt):
-                shutil.copy(os.path.join(recpath,title+".mp4"), os.path.join(movepath,title+".mp4"))
+                try:
+                    if os.path.exists(os.path.join(recpath,title+".mp4")):
+                        shutil.copy(os.path.join(recpath,title+".mp4"), os.path.join(movepath,title+".mp4"))
+                    elif os.path.exists(os.path.join(recpath,title+".mkv")):
+                        shutil.copy(os.path.join(recpath,title+".mkv"), os.path.join(movepath,title+".mkv"))
+                except Exception, inst:
+                    errtxt="Error happened in type_encode_que in timerec.\n"
+                    errtxt=errtxt+"move mkv/mp4 error.\n"
+                    errtxt=errtxt+str(type(inst))+"\n"
+                    errtxt=errtxt+str(inst)
+                    recdblist.addlog(os.path.join(recpath,title+".ts"), errtxt, "timerec-move(Encode) error")
                 recdb.rec_reckey(recdblist.REC_MOVE_END, title, chtxt, btime, etime, opt)
             recdb.rec_reckey(typetxtfin, title, chtxt, btime, etime, opt)
             sys.exit()
